#
# spec file for package evdi
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _dllibdir %{_libdir}/displaylink
%define lname   libevdi1

Name:           evdi
Release:        1.12
Version:        1.14.8
Summary:        Extensible Virtual Display Interface (EVDI) is a Linux Kernel Module
License:        GPL-2.0-only AND LGPL-2.1-only
Group:          System/Kernel
URL:            https://github.com/DisplayLink/evdi
Source0:        evdi-%{version}.tar
Source1:        evdi-kmp-preamble
Source2:        evdi-rpmlintrc
Patch0:         evdi-Enable-compilation-against-15.5.patch
BuildRequires:  %{kernel_module_package_buildreqs}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libdrm)
# needssslcertforbuild
%kernel_module_package -p %{_sourcedir}/evdi-kmp-preamble -c %{_sourcedir}/_projectcert.crt
%define kver %(uname -r | sed 's/-default//')

%description
The Extensible Virtual Display Interface (EVDI) is a Linux kernel module
that enables management of multiple screens, allowing user-space programs
to take control over what happens with the image. It is essentially
a virtual display you can add, remove and receive screen updates for, in
an application that uses the libevdi library.

%package -n %{lname}
Summary:        LibEVDI Library
Group:          System/Libraries
Requires:       evdi-kmp

%description -n %{lname}
The Extensible Virtual Display Interface (EVDI) is a Linux kernel module
that enables management of multiple screens, allowing user-space programs
to take control over what happens with the image. It is essentially
a virtual display you can add, remove and receive screen updates for, in
an application that uses the libevdi library.

%package devel
Summary:        Development files for libevdi Library
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
The Extensible Virtual Display Interface (EVDI) is a Linux kernel module
that enables management of multiple screens, allowing user-space programs
to take control over what happens with the image. It is essentially
a virtual display you can add, remove and receive screen updates for, in
an application that uses the libevdi library.

%prep
%setup -q
%if 0%{?sle_version} == 150500
%patch -P 0 -p1
%endif

%build
pushd library
%make_build
mv LICENSE LICENSE.library
popd

pushd module
sed -i 's:/kernel/drivers/gpu/drm/evdi:/extra:' Makefile
mv LICENSE LICENSE.module
set -- *
mkdir source
mv "$@" source/
mkdir obj
for flavor in %flavors_to_build; do
       rm -rf obj/$flavor
       cp -r source obj/$flavor
       make %{?_smp_mflags} -C %kernel_module_directory/%{kver}-$flavor/build M=$PWD/obj/$flavor \
       modules
done

%install
pushd library
%make_install PREFIX=%{_prefix} LIBDIR=%{_dllibdir}
install -m644 -D evdi_lib.h %{buildroot}%{_includedir}/%{name}/evdi_lib.h
popd

pushd module
for flavor in %flavors_to_build; do
       make -C %kernel_module_directory/%{kver}-$flavor/build M=$PWD/obj/$flavor \
       INSTALL_MOD_PATH=%{buildroot} \
       INSTALL_MOD_DIR=/extra \
       modules_install
done

%post   -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%files
%license {library,module/source}/LICENSE.*
%doc README.md docs

%files -n %{lname}
%dir %{_dllibdir}
%{_dllibdir}/libevdi.so
%{_dllibdir}/libevdi.so.1*

%files devel
%{_includedir}/%{name}

%changelog
* Thu Jan  2 2025 joan.torres@suse.com
- Update to version 1.14.8:
  * Set version to 1.14.8
  * Fetch checkpatch script from linux kernel mirror
  * Check github/main branch against linux master branch
  * Test only main branch against linux kernel master
  * Add libevdi{abi} conflicting packages for evdi deb package
  * Validate build with CONFIG_FB define
  * Fix check for available git mirror with 5 sec timeout
  * Workaround Gnome/mutter issue where it is not waiting for primary gpu
  * change preinst part to runtime and refactor preinst
  * auto uninstall existing dlm
* Fri Oct  4 2024 joan.torres@suse.com
- Update to version 1.14.7:
  * Set version to 1.14.7
  * Fix venv for pytest.run.sh
  * Test that card opening does not take too long
  * Do not wait for master on wayland session
  * Test that monitor power off event is sent on vt terminal swithc when user is connected
  * Test that no monitor power off events are sent when user driver is not connected
  * Test that evdi_painter listens to VT notifications
  * Blank evdi display on switch to tty console. Fixes GH-474.
  * Add evdi_test_data base test context stucture and drm_device removal hook
  * Make evdi_painter_dpms_notify to take evdi_painter as argument instead of evdi_device
- With this update fix-v1.14.5-build.patch is not needed anymore.
* Fri Aug  2 2024 Joan Torres <joan.torres@suse.com>
- Fix adding uefi cert for the kernel module
* Fri Aug  2 2024 Joan Torres <joan.torres@suse.com>
- Update patch evdi-Enable-compilation-against-15.5.patch
* Fri Aug  2 2024 Joan Torres <joan.torres@suse.com>
- Update to version 1.14.5
  * This allows building against the 6.10 kernel
  * Added fix-v1.14.5-build.patch that adds a missing parameter when
    building the module.
* Tue Jul 16 2024 Joan Torres <joan.torres@suse.com>
- Build kernel module considering the different flavors an arch can have.
* Wed May  8 2024 Joan Torres <joan.torres@suse.com>
- With the latest update these patches are not needed anymore:
  * evdi-Enable-compilation-against-15.6.patch
  * evdi-Resolve-compiler-errors-when-compiling-against-Linux.patch
* Tue May  7 2024 Joan Torres <joan.torres@suse.com>
- Add evdi-rpmlintrc to sources
* Tue May  7 2024 joan.torres@suse.com
- Update to version 1.14.4:
  * Set version to 1.14.4
  * Fix unsafe use of strlen
  * Set version to 1.14.3
  * Fix pyevdi test_check_device test - on some systems card0 can be evdi device
  * Remove test package from pyevdi tests
  * Add cursor_set/cursor_move handlers to PyEvdi bindings
  * Add Card::enableCursorEvents python binding wit tests
  * Fix segfault in pyevdi tests and add pytest.run script to run the tests
  * Use github when linux mirror does not exists
  * Do not allow to mmap imported gem objects via dumb gem api
* Tue Mar 12 2024 joan.torres@suse.com
- Update to version 1.14.2:
  * Set version to 1.14.2
  * Use mirror of linux when possible
  * Run build against kernel stage bash
  * Add other non-project related directories to Synopsys exculded dirs
  * Publish build when build from main branch
  * Minor script improvements
  * No std::format in debian bullseye and bookworm
  * Rearrange ifdefs to becompliant for ./ci/export_for_kernel script
  * Add SonarQube scans for EVDI
  * Request reboot when logname returns error
* Tue Mar 12 2024 Joan Torres <joan.torres@suse.com>
- Add libevdi.so to libevdi package.
  * The DisplayLinkManager uses it.
* Thu Feb 22 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Feb  2 2024 Joan Torres <joan.torres@suse.com>
- Add evdi-kmp dependency.
* Fri Feb  2 2024 Joan Torres <joan.torres@suse.com>
- At %%kernel_module_package add _projectcert.crt to automatically add
  the signing key to MOK.
  On new reboot a MOK menu appears and the key must be manually enrolled
  using the admin password.
* Mon Jan 29 2024 joan.torres@suse.com
- Update to version 1.14.1:
  * Set version to 1.14.1
  * Remove buildDescription from jenkins job
  * Use strscpy instead of strcpy
  * Set version to 1.14.0
  * Maintain support for legacy connect call for clients not requiring new functionality
  * Remove unused reservation object
  * Remove check_version from job
  * Remove unnecessary CFLAGS when building module in kernel
  * Run style check using checkstyle perl script from master
  * Only include drm.h when building the module
* Mon Jan 29 2024 Joan Torres <joan.torres@suse.com>
- Init package.
